@@ -4,5 +4,6 @@ from . import views
 
 
 urlpatterns = patterns('',
-    url(r'^(?P<uri>.*)responsive/$', views.ResponsiveTestView.as_view()),
+    url(r'^(?P<uri>.*)responsive/(?P<type>.*)/?$',
+            views.ResponsiveTestView.as_view()),
 )
